from trapper.metrics.input_handlers.input_handler import MetricInputHandler
from trapper.metrics.input_handlers.language_generation_input_handler import (
    MetricInputHandlerForLanguageGeneration,
)
from trapper.metrics.input_handlers.question_answering_input_handler import (
    MetricInputHandlerForQuestionAnswering,
)
from trapper.metrics.input_handlers.token_classification_input_handler import (
    MetricInputHandlerForTokenClassification,
)
